@@ -33,44 +33,48 @@
 
 /* These functions allocate the return value internally
  */
-int _gnutls_m_plaintext2compressed(gnutls_session_t session,
-				   gnutls_datum_t * compressed,
-				   gnutls_datum_t plaintext)
+int
+_gnutls_m_plaintext2compressed (gnutls_session_t session,
+				gnutls_datum_t * compressed,
+				const gnutls_datum_t* plaintext)
 {
-    int size;
-    opaque *data;
+  int size;
+  opaque *data;
 
-    size =
-	_gnutls_compress(session->connection_state.write_compression_state,
-			 plaintext.data, plaintext.size, &data,
-			 MAX_RECORD_SEND_SIZE + 1024);
-    if (size < 0) {
-	gnutls_assert();
-	return GNUTLS_E_COMPRESSION_FAILED;
+  size =
+    _gnutls_compress (session->connection_state.write_compression_state,
+		      plaintext->data, plaintext->size, &data,
+		      MAX_RECORD_SEND_SIZE + EXTRA_COMP_SIZE);
+  if (size < 0)
+    {
+      gnutls_assert ();
+      return GNUTLS_E_COMPRESSION_FAILED;
     }
-    compressed->data = data;
-    compressed->size = size;
+  compressed->data = data;
+  compressed->size = size;
 
-    return 0;
+  return 0;
 }
 
-int _gnutls_m_compressed2plaintext(gnutls_session_t session,
-				   gnutls_datum_t * plain,
-				   gnutls_datum_t compressed)
+int
+_gnutls_m_compressed2plaintext (gnutls_session_t session,
+				gnutls_datum_t * plain,
+				const gnutls_datum_t* compressed)
 {
-    int size;
-    opaque *data;
+  int size;
+  opaque *data;
 
-    size =
-	_gnutls_decompress(session->connection_state.
-			   read_compression_state, compressed.data,
-			   compressed.size, &data, MAX_RECORD_RECV_SIZE);
-    if (size < 0) {
-	gnutls_assert();
-	return GNUTLS_E_DECOMPRESSION_FAILED;
+  size =
+    _gnutls_decompress (session->connection_state.
+			read_compression_state, compressed->data,
+			compressed->size, &data, MAX_RECORD_RECV_SIZE);
+  if (size < 0)
+    {
+      gnutls_assert ();
+      return GNUTLS_E_DECOMPRESSION_FAILED;
     }
-    plain->data = data;
-    plain->size = size;
+  plain->data = data;
+  plain->size = size;
 
-    return 0;
+  return 0;
 }
